EthAccount extension
- on
Methods
-
balance(
{required List< String> addresses}) → Future<EtherScanBalanceModel> -
Available on EtherscanAPI, provided by the EthAccount extension
Returns the balance of a sepcific account -
getMinedBlocks(
{required String address}) → Future< EtherScanMintedBlocksModel> -
Available on EtherscanAPI, provided by the EthAccount extension
Get a list of blocks that a specific account has mineds -
tokenBalance(
{required String? address, required String? contractAddress, String? tokenName}) → Future< EtherScanTokenBalanceModel> -
Available on EtherscanAPI, provided by the EthAccount extension
Returns the amount of Tokens a specific account owns. -
tokennFttx(
{required String? address, String? contractAddress, Object startblock = 0, String endblock = 'latest', int page = 1, int offset = 100, EtherSort sort = EtherSort.asc}) → Future< EtherscanTokenFftxModel> -
Available on EtherscanAPI, provided by the EthAccount extension
Get a list of "ERC721 - Token Transfer Events" by Address -
tokenTx(
{required String? address, String? contractAddress, Object startblock = 0, String endblock = 'latest', int page = 1, int offset = 100, EtherSort sort = EtherSort.asc}) → Future< EtherScanMintedTokenTxModel> -
Available on EtherscanAPI, provided by the EthAccount extension
Get a list of "ERC20 - Token Transfer Events" by Address -
txList(
{required String? address, Object startblock = 0, String? endblock, int page = 1, int offset = 100, EtherSort sort = EtherSort.asc}) → Future< EtherScanTxListModel> -
Available on EtherscanAPI, provided by the EthAccount extension
Get a list of transactions for a specfic address -
txListInternal(
{String? txhash, String? address, Object startblock = 0, String? endblock = 'latest', EtherSort sort = EtherSort.asc}) → Future< EtherScanTxInternalModel> -
Available on EtherscanAPI, provided by the EthAccount extension
Get a list of internal transactions